NotchPayConfigurationException class

Thrown when the SDK is used incorrectly (e.g. missing configuration).

Inheritance

Constructors

NotchPayConfigurationException(String message)
Creates a configuration error with the given message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human readable explanation of what went wrong.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited