NotchPayCustomerService class

Manage NotchPay customers.

See https://developers.notchpay.co/api/customer

Constructors

NotchPayCustomerService(NotchPayClient _client)
Creates the service, using client for every request.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

block(String reference) Future<void>
Blocks a customer, preventing them from paying again.
create({required String name, String? email, String? phone, String? description, NotchPayAddress? address, NotchPayAddress? shipping}) Future<NotchPayCustomer>
Creates a new customer.
delete(String reference) Future<void>
Permanently deletes a customer.
fetch(String reference) Future<NotchPayCustomer>
Fetches a single customer by reference.
list({int? limit, int? page}) Future<List<NotchPayCustomer>>
Lists customers, page by limit.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unblock(String reference) Future<void>
Unblocks a previously blocked customer.
update(String reference, {String? name, String? email, String? phone, String? description, NotchPayAddress? address, NotchPayAddress? shipping}) Future<NotchPayCustomer>
Updates an existing customer.

Operators

operator ==(Object other) bool
The equality operator.
inherited